//******************************************************************
//* GECKO MOTOR DRIVER BOARD
//* LAST UPDATED 02/13/2008
//* FIRMWARE BY FRED EADY FOR SERVO MAGAZINE
//* CHANGES/ADDITIONS
//******************************************************************
#include <pic18.h>
#include <string.h>
#include <stdio.h>
#include <ctype.h>
#include <htc.h>
#include<stdlib.h>

// Settings for PIC18F2620
__CONFIG(1,IESODIS & FCMDIS & RCIO);
__CONFIG(2,BORDIS & PWRTDIS & WDTDIS);
__CONFIG(3,MCLREN & LPT1DIS & PBDIGITAL);
__CONFIG(4,DEBUGEN & LVPDIS & XINSTDIS & STVREN);
__CONFIG(5,UNPROTECT);
__CONFIG(6,WRTEN);
__IDLOC(0213);
//******************************************************************
//*	FUNCTION PROTOTYPES
//******************************************************************
void interrupt TIMERS(void);
void init(void);
//******************************************************************
//*	PIC18F2620 RAM Definitions
//******************************************************************
unsigned int temp16,scratch16;
char temp8,scratch8,bytein;
unsigned int tmsecs1,imsecs1;
char tsecs1,isecs1;
//******************************************************************
//*	GECKO CONTROL INTERFACE DEFINITONS
//******************************************************************
#define	DISABLE			LATB0
#define	DIR				LATB1
#define	CW				1
#define CCW				0
#define ON				1
#define OFF				0
						

//******************************************************************
//*	INTERRUPT DEFINITIONS
//******************************************************************
#define		disable_TMR1int  	TMR1IE = 0
#define		enable_TMR1int	 	TMR1IE = 1

#define		enable_GLOBALint  	IPEN = 0;				\
							  	GIE = 1;				\
							  	PEIE = 1;
#define		disable_GLOBALint 	IPEN = 0;				\
							  	GIE = 0;				\
							  	PEIE = 0;
#define		TIMER1ON			TMR1ON = 1
#define		TIMER1OFF			TMR1ON = 0
#define		TIMER2ON		  	TMR2ON = 1
#define		TIMER2OFF		  	TMR2ON = 0

#define mdelay1(msecdelay)		TIMER1OFF;					\
								TMR1IF = 0;					\
								imsecs1 = 0;				\
								tmsecs1 = 0;				\
								TIMER1ON;					\
								while(tmsecs1 < msecdelay);
#define	sdelay1(secdelay)		TIMER1OFF;					\
								TMR1IF = 0;					\
								imsecs1 = 0;				\
								tmsecs1 = 0;				\
								isecs1 = 0;					\
								tsecs1 = 0;					\
								TIMER1ON;					\
								while(tsecs1 < secdelay);

//******************************************************************
//*	INTERRUPT HANDLER ROUTINE
//******************************************************************
void interrupt TIMERS(void)
{

	if((TMR1IF && TMR1IE))
	{
		TMR1IF = 0;
		TMR1H = 0xF8;	
		TMR1L = 0x31;

		++tmsecs1;
		if(++imsecs1 == 1000)
		{
			imsecs1 = 0;
			++isecs1;
			++tsecs1;
		}
	}
}
//****************************************************************************
//*	INITIALIZE ROUTINE
//****************************************************************************
void init()
{
//****************************************************************************
//*	INITIALIZE CLOCK AND IO PORTS
//****************************************************************************
	OSCCON = 0x70;
	PLLEN = 0;
	TRISA = 0b11111111;
	TRISB = 0b11111100;
	TRISC = 0b11111011;
//******************************************************************
//*	CONFIGURE A2D AND COMPARATORS
//******************************************************************
	//ADCON0 = 0b00000000;
	ADCON1 = 0b00001111;
	//ADCON2 = 0b10111111;
	ADON = 0;
	CMCON = 0x07;
//******************************************************************
//*	INITIALIZE PWM
//******************************************************************
	CCP1CON = 0x3F;
	CCPR1L = 0x1F;
	T2CON = 0x07; 
	PR2 = 50;
//******************************************************************
//*	CONFIGURE AND START TIMER1
//* SET TO OVERFLOW EVERY 1mS
//******************************************************************
	//F831 = 8MHz
	//E0C1 = 32MHz
	TIMER1OFF;
	T1CON = 0b00000000;
	TMR1H = 0xF8;
	TMR1L = 0x31;
	TIMER1ON;
//******************************************************************
//*	CONFIGURE EXTERNAL INTERRUPTS
//******************************************************************
	enable_TMR1int;
    enable_GLOBALint;
}
void main(void)
{
//******************************************************************
//*	INITIALIZE
//******************************************************************
	init();
	DISABLE = OFF;
	DIR = CW;
	sdelay1(2);
	TIMER2ON;
//******************************************************************
//*	MAIN SERVICE LOOP
//******************************************************************
	do{
		sdelay1(5);
		DIR ^= 1;
		
		
	}while(1);
}
